==> konsole_24.12.3.orig.tar.xz: konsole-24.12.3/README.md <==
# Konsole - KDE's Terminal Emulator

Konsole is a terminal program for KDE.

As well as being a standalone program, it is also used by other KDE programs
such as the Kate editor and KDevelop development environment to provide easy
access to a terminal window. Konsole's features and usage are explained and
illustrated in the Konsole handbook, which can be accessed by browsing to
`help:/konsole` in Konqueror.


## Directory Structure

| Directory          | Description                                                                                                                                                                        |
| ------------------ | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `/doc/user`        | README files, primarily for advanced users, explaining various aspects of Konsole such as fonts and keyboard handling in-depth.                                                    |
| `/doc/developer`   | README files and resources for developers of Konsole. This includes information on the design of Konsole's internals and the VT100 terminal on which Konsole's emulation is based. |
| `/src`             | Source code for Konsole, including the embedded versions of Konsole which are used in Kate, KDevelop and others.                                                                   |
| `/desktop`         | .desktop files for Konsole, used to launch the program from KDE's various menus and other application launchers.                                                                   |
| `/data`            | Data files for use with Konsole as well as the keyboard setup and color schemes provided with Konsole.                                                                             |

## Contact

Up-to-date information about the latest releases can be found on Konsole's
website at https://konsole.kde.org. Discussions about Konsole's development are
held on the konsole-devel mailing list, which can be accessed at
https://mail.kde.org/mailman/listinfo/konsole-devel.

## Quick Links
- [KDE Release Schedule](https://community.kde.org/Schedules)
- [Official Homepage](https://konsole.kde.org)
- [Builds](https://invent.kde.org/utilities/konsole/-/pipelines)
- [Forums](https://discuss.kde.org)
- [Konsole Bug Reports per Component](https://bugs.kde.org/describecomponents.cgi?product=konsole)

==> konsole-25.11.80.tar.xz: konsole-25.11.80/README.md <==
# Konsole - KDE's Terminal Emulator

Konsole is a terminal program for KDE.

As well as being a standalone program, it is also used by other KDE programs
such as the Kate editor and KDevelop development environment to provide easy
access to a terminal window. Konsole's features and usage are explained and
illustrated in the Konsole handbook, which can be accessed by browsing to
`help:/konsole` in Konqueror.


## Directory Structure

| Directory          | Description                                                                                                                                                                        |
| ------------------ | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `/doc/user`        | README files, primarily for advanced users, explaining various aspects of Konsole such as fonts and keyboard handling in-depth.                                                    |
| `/doc/developer`   | README files and resources for developers of Konsole. This includes information on the design of Konsole's internals and the VT100 terminal on which Konsole's emulation is based. |
| `/src`             | Source code for Konsole, including the embedded versions of Konsole which are used in Kate, KDevelop and others.                                                                   |
| `/desktop`         | .desktop files for Konsole, used to launch the program from KDE's various menus and other application launchers.                                                                   |
| `/data`            | Data files for use with Konsole as well as the keyboard setup and color schemes provided with Konsole.                                                                             |

## Contact

Up-to-date information about the latest releases can be found on Konsole's
website at https://konsole.kde.org. Discussions about Konsole's development are
held on the konsole-devel mailing list, which can be accessed at
https://mail.kde.org/mailman/listinfo/konsole-devel.

## Quick Links
- [KDE Release Schedule](https://community.kde.org/Schedules)
- [Official Homepage](https://konsole.kde.org)
- [Builds](https://invent.kde.org/utilities/konsole/-/pipelines)
- [Forums](https://discuss.kde.org/tag/konsole)
- [Konsole Bug Reports ](https://bugs.kde.org/describecomponents.cgi?product=konsole)
